@@ -20,6 +20,7 @@ G_DEFINE_TYPE(TangleDraggableActor, tangle_draggable_actor, TANGLE_TYPE_FLOATING
 
 enum {
 	PROP_0,
+	PROP_DRAGGING_ENABLED,
 	PROP_FLOATING_MODE_DRAGGED,
 	PROP_PLACEHOLDER_OPACITY_DRAGGED,
 	PROP_DRAGGING_THRESHOLD_X,
@@ -42,6 +43,9 @@ struct _TangleDraggableActorPrivate {
 	
 	TangleDragging* dragging;
 	gulong captured_event_handler_id;
+	
+	guint dragging_enabled : 1;
+	
 	guint dragging_effective : 1;
 	guint descendant_interacting : 1;
 	guint descendant_dragging : 1;
@@ -114,6 +118,18 @@ void tangle_dragging_set_droppable_actor(TangleDragging* dragging, TangleDroppab
 	}
 }
 
+gboolean tangle_draggable_actor_get_dragging_enabled(TangleDraggableActor* draggable_actor) {
+
+	return draggable_actor->priv->dragging_enabled;
+}
+
+void tangle_draggable_actor_set_dragging_enabled(TangleDraggableActor* draggable_actor, gboolean dragging_enabled) {
+	if (draggable_actor->priv->dragging_enabled != dragging_enabled) {
+		draggable_actor->priv->dragging_enabled = dragging_enabled;
+		g_object_notify(G_OBJECT(draggable_actor), "dragging-enabled");
+	}
+}
+
 gfloat tangle_draggable_actor_get_dragging_threshold_x(TangleDraggableActor* draggable_actor) {
 
 	return draggable_actor->priv->dragging_threshold_x;
@@ -187,20 +203,22 @@ static gboolean tangle_draggable_actor_button_press_event(ClutterActor* actor, C
 	
 	draggable_actor = TANGLE_DRAGGABLE_ACTOR(actor);
 	
-	clutter_actor_get_transformed_position(actor, &x, &y);
-	draggable_actor->priv->dragging = tangle_dragging_new(draggable_actor);
-	draggable_actor->priv->dragging->x = event->x;
-	draggable_actor->priv->dragging->y = event->y;
-	draggable_actor->priv->dragging->anchor_x = event->x - x;
-	draggable_actor->priv->dragging->anchor_y = event->y - y;
-	draggable_actor->priv->dragging->dx = event->x - x - draggable_actor->priv->dragging->anchor_x;
-	draggable_actor->priv->dragging->dy = event->y - y - draggable_actor->priv->dragging->anchor_y;
-	clutter_actor_get_size(actor, &width, &height);
-	draggable_actor->priv->dragging->center_x = x + width / 2;
-	draggable_actor->priv->dragging->center_y = y + height / 2;
+	if (draggable_actor->priv->dragging_enabled) {
+		clutter_actor_get_transformed_position(actor, &x, &y);
+		draggable_actor->priv->dragging = tangle_dragging_new(draggable_actor);
+		draggable_actor->priv->dragging->x = event->x;
+		draggable_actor->priv->dragging->y = event->y;
+		draggable_actor->priv->dragging->anchor_x = event->x - x;
+		draggable_actor->priv->dragging->anchor_y = event->y - y;
+		draggable_actor->priv->dragging->dx = event->x - x - draggable_actor->priv->dragging->anchor_x;
+		draggable_actor->priv->dragging->dy = event->y - y - draggable_actor->priv->dragging->anchor_y;
+		clutter_actor_get_size(actor, &width, &height);
+		draggable_actor->priv->dragging->center_x = x + width / 2;
+		draggable_actor->priv->dragging->center_y = y + height / 2;
 
-	draggable_actor->priv->dragging_effective = FALSE;
-	draggable_actor->priv->captured_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "captured-event", G_CALLBACK(on_captured_event), actor);
+		draggable_actor->priv->dragging_effective = FALSE;
+		draggable_actor->priv->captured_event_handler_id = g_signal_connect(clutter_actor_get_stage(actor), "captured-event", G_CALLBACK(on_captured_event), actor);
+	}
 
 	return FALSE;
 }
@@ -236,6 +254,9 @@ static void tangle_draggable_actor_set_property(GObject* object, guint prop_id,
 	draggable_actor = TANGLE_DRAGGABLE_ACTOR(object);
 
 	switch (prop_id) {
+		case PROP_DRAGGING_ENABLED:
+			tangle_draggable_actor_set_dragging_enabled(draggable_actor, g_value_get_boolean(value));
+			break;
 		case PROP_DRAGGING_THRESHOLD_X:
 			tangle_draggable_actor_set_dragging_threshold_x(draggable_actor, g_value_get_float(value));
 			break;
@@ -257,6 +278,9 @@ static void tangle_draggable_actor_get_property(GObject* object, guint prop_id,
 	draggable_actor = TANGLE_DRAGGABLE_ACTOR(object);
 
         switch (prop_id) {
+		case PROP_DRAGGING_ENABLED:
+			g_value_set_boolean(value, draggable_actor->priv->dragging_enabled);
+			break;
 		case PROP_DRAGGING_THRESHOLD_X:
 			g_value_set_float(value, draggable_actor->priv->dragging_threshold_x);
 			break;
@@ -307,6 +331,17 @@ static void tangle_draggable_actor_class_init(TangleDraggableActorClass* draggab
 	draggable_actor_class->do_dragging = tangle_draggable_actor_do_dragging;
 	draggable_actor_class->end_dragging = tangle_draggable_actor_end_dragging;
 
+	/**
+	 * TangleDraggableActor:dragging-enabled:
+	 *
+	 * Whether to enable dragging.
+	 */
+	g_object_class_install_property(gobject_class, PROP_DRAGGING_ENABLED,
+	                                g_param_spec_boolean("dragging-enabled",
+	                                                     "Dragging enabled",
+	                                                     "Whether to enable dragging",
+	                                                     TRUE,
+	                                                     G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 	/**
 	 * TangleDraggableActor:dragging-threshold-x:
 	 */
@@ -330,7 +365,7 @@ static void tangle_draggable_actor_class_init(TangleDraggableActorClass* draggab
 	 *
 	 * Whether to use anchor (touch) point or center point as a reference when checking droppable area.
 	 */
-	g_object_class_install_property(gobject_class, PROP_DRAGGING_THRESHOLD_Y,
+	g_object_class_install_property(gobject_class, PROP_USE_ANCHOR_POINT,
 	                                g_param_spec_boolean("use-anchor-point",
 	                                                     "Use anchor point",
 	                                                     "Whether to use anchor (touch) point or center point as a reference",
@@ -378,6 +413,7 @@ static void tangle_draggable_actor_init(TangleDraggableActor* draggable_actor) {
 	draggable_actor->priv = G_TYPE_INSTANCE_GET_PRIVATE(draggable_actor, TANGLE_TYPE_DRAGGABLE_ACTOR, TangleDraggableActorPrivate);
 	clutter_actor_set_reactive(CLUTTER_ACTOR(draggable_actor), TRUE);
 
+	draggable_actor->priv->dragging_enabled = TRUE;
 	draggable_actor->priv->floating_mode_dragged = TANGLE_FLOATING_MODE_PLACEHOLDER;
 	draggable_actor->priv->placeholder_opacity_dragged = 50;
 }
@@ -418,9 +454,8 @@ static gboolean on_captured_event(ClutterActor* actor, ClutterEvent* event, gpoi
 			}
 		} else {
 			if (event->type == CLUTTER_MOTION && !draggable_actor->priv->descendant_dragging &&
-			    (!draggable_actor->priv->descendant_interacting ||
-			     ABS_F(draggable_actor->priv->dragging->dy) > draggable_actor->priv->dragging_threshold_x ||
-			     ABS_F(draggable_actor->priv->dragging->dx) > draggable_actor->priv->dragging_threshold_y)) {
+			    (ABS_F(draggable_actor->priv->dragging->dx) > draggable_actor->priv->dragging_threshold_x ||
+			     ABS_F(draggable_actor->priv->dragging->dy) > draggable_actor->priv->dragging_threshold_y)) {
 				draggable_actor->priv->dragging_effective = TRUE;
 				handle_droppable_actor(draggable_actor->priv->dragging);
 				g_signal_emit(draggable_actor, signals[BEGIN_DRAGGING], 0, draggable_actor->priv->dragging, &handled);	
