@@ -21,7 +21,8 @@ G_DEFINE_ABSTRACT_TYPE(TangleLayout, tangle_layout, G_TYPE_OBJECT);
 
 enum {
 	PROP_0,
-	PROP_CONTAINER
+	PROP_WIDGET,
+	PROP_DIRECTION
 };
 
 enum {
@@ -38,6 +39,28 @@ struct _TangleLayoutPrivate {
 static GQuark quark_layout_meta = 0;
 static guint signals[LAST_SIGNAL];
 
+static const GEnumValue layout_direction_values[] = {
+	{ TANGLE_LAYOUT_DIRECTION_LTR_TTB, "TANGLE_LAYOUT_DIRECTION_LTR_TTB", "ltr-ttb" },
+	{ TANGLE_LAYOUT_DIRECTION_RTL_TTB, "TANGLE_LAYOUT_DIRECTION_RTL_TTB", "rtl-ttb" },
+	{ TANGLE_LAYOUT_DIRECTION_LTR_BTT, "TANGLE_LAYOUT_DIRECTION_LTR_BTT", "ltr-btt" },
+	{ TANGLE_LAYOUT_DIRECTION_RTL_BTT, "TANGLE_LAYOUT_DIRECTION_RTL_BTT", "rtl-btt" },
+	{ TANGLE_LAYOUT_DIRECTION_TTB_LTR, "TANGLE_LAYOUT_DIRECTION_TTB_LTR", "ttb-ltr" },
+	{ TANGLE_LAYOUT_DIRECTION_TTB_RTL, "TANGLE_LAYOUT_DIRECTION_TTB_RTL", "ttb-rtl" },
+	{ TANGLE_LAYOUT_DIRECTION_BTT_LTR, "TANGLE_LAYOUT_DIRECTION_BTT_LTR", "btt-ltr" },
+	{ TANGLE_LAYOUT_DIRECTION_BTT_RTL, "TANGLE_LAYOUT_DIRECTION_BTT_RTL", "btt-rtl" },
+	{ 0, NULL, NULL }
+};
+
+GType tangle_layout_direction_get_type(void) {
+	static GType type = 0;
+	
+	if (!type) {
+		type = g_enum_register_static("TangleLayoutDirection", layout_direction_values);
+	}
+	
+	return type;
+}
+
 TangleWidget* tangle_layout_get_widget(TangleLayout* layout) {
 
 	return layout->priv->widget;
@@ -226,7 +249,7 @@ TangleLayoutDirection tangle_layout_get_direction(TangleLayout* layout) {
 void tangle_layout_set_direction(TangleLayout* layout, TangleLayoutDirection direction) {
 	if (layout->priv->direction != direction) {
 		layout->priv->direction = direction;
-/* TODO:		g_object_notify(G_OBJECT(layout), "direction"); */
+		g_object_notify(G_OBJECT(layout), "direction");
 		g_signal_emit(layout, signals[CHANGED], 0);
 	}
 }
@@ -256,9 +279,12 @@ static void tangle_layout_set_property(GObject* object, guint prop_id, const GVa
 	layout = TANGLE_LAYOUT(object);
 
 	switch (prop_id) {
-		case PROP_CONTAINER:
+		case PROP_WIDGET:
 			tangle_layout_set_widget(layout, TANGLE_WIDGET(g_value_get_object(value)));
 			break;
+		case PROP_DIRECTION:
+			tangle_layout_set_direction(layout, g_value_get_enum(value));
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 			break;
@@ -271,9 +297,12 @@ static void tangle_layout_get_property(GObject* object, guint prop_id, GValue* v
 	layout = TANGLE_LAYOUT(object);
 
         switch (prop_id) {
-		case PROP_CONTAINER:
+		case PROP_WIDGET:
 			g_value_set_object(value, tangle_layout_get_widget(layout));
 			break;
+		case PROP_DIRECTION:
+			g_value_set_enum(value, layout->priv->direction);
+			break;
 	        default:
 		        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		        break;
@@ -302,13 +331,25 @@ static void tangle_layout_class_init(TangleLayoutClass* klass) {
 
 	/**
 	 * TangleLayout:widget:
+	 *
+	 * The widget of which children is allocated with this layout.
 	 */
-	g_object_class_install_property(gobject_class, PROP_CONTAINER,
+	g_object_class_install_property(gobject_class, PROP_WIDGET,
 	                                g_param_spec_object ("widget",
 	                                "Widget",
 	                                "The widget of which children is allocated with this layout",
 	                                TANGLE_TYPE_WIDGET,
 	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
+	/**
+	 * TangleLayout:direction:
+	 */
+	g_object_class_install_property(gobject_class, PROP_DIRECTION,
+	                                g_param_spec_enum("direction",
+	                                "Direction",
+	                                "The direction of which children are laid out",
+	                                TANGLE_TYPE_LAYOUT_DIRECTION,
+					TANGLE_LAYOUT_DIRECTION_LTR_TTB,
+	                                G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK |G_PARAM_STATIC_BLURB));
 
 	signals[CHANGED] = g_signal_new("changed",
 					G_TYPE_FROM_CLASS(gobject_class),
